\name{scde.error.models}
\alias{scde.error.models}
\title{Fit single-cell error/regression models}
\usage{
scde.error.models(counts, groups = NULL, min.nonfailed = 3,
  threshold.segmentation = T, min.count.threshold = 4,
  zero.count.threshold = min.count.threshold, zero.lambda = 0.1,
  save.crossfit.plots = F, save.model.plots = T, n.cores = 12,
  min.size.entries = 2000, max.pairs = 1000, verbose = 0)
}
\arguments{
  \item{counts}{read count matrix. The rows correspond to
  genes (should be named), columns correspond to individual
  cells. The matrix should contain integer counts}

  \item{groups}{an optional factor describing grouping of
  different cells. If provided, the cross-fits and the
  expected expression magnitudes will be determined
  separately within each group. The factor should have the
  same length as ncol(counts).}

  \item{min.nonfailed}{}

  \item{threshold.segmentation}{use a fast threshold-based
  segmentation during cross-fit (default: T)}

  \item{min.count.threshold}{the number of reads to use to
  guess which genes may have "failed" to be detected in a
  given measurement (default 4 reads)}

  \item{zero.count.threshold}{}

  \item{zero.lambda}{the rate of the Poisson (failure)
  component (default : 0.1)}

  \item{save.crossfit.plots}{whether png files showing
  cross-fit segmentations should be written out (default:
  F)}

  \item{save.model.plots}{whether pdf files showing model
  fits should be written out (default=T)}

  \item{n.cores}{number of cores to use}

  \item{min.size.entries}{minimum number of genes to use
  when determining expected expression magnitude during
  model fitting}

  \item{max.pairs}{maximum number of cross-fit comparisons
  that should be performed per group (default 1000)}

  \item{verbose}{1 for increased output}
}
\value{
a model matrix, with rows corresponding to different cells,
and columns representing different parameters of the
determined models
}
\description{
Fit error models given a set of single-cell data (counts)
and an optional grouping factor (groups). The cells (within
each group) are first cross-compared to determine a subset
of genes showing consistent expression. The set of genes is
then used to fit a mixture model (Poisson-NB mixture, with
expression-dependent concomitant).
}

